kdiagram.plot.evaluation.plot\_polar\_classification\_report
============================================================

.. currentmodule:: kdiagram.plot.evaluation

.. autofunction:: plot_polar_classification_report